﻿using System;
using UnityEngine;
using System.Collections;

/// <summary>
/// This MonoBehaviour implements the Cloud Reco Event handling for this sample.
/// It registers itself at the CloudRecoBehaviour and is notified of new search results as well as error messages
/// The current state is visualized and new results are enabled using the TargetFinder API.
/// </summary>
 
/// <summary>
/// This class implements the Cloud Reco Event handling for the project. 
/// It registers itself at the CloudRecoBehaviour and is notified of new search results as well as error messages
/// The current state is visualized and new results are enabled using the TargetFinder API.
/// The class also draws and handles GUI elements that are used in both phase1 and phase2 GUIs. 
/// </summary>

public class CloudRecoEventHandler : MonoBehaviour, ICloudRecoEventHandler
{
    #region PRIVATE_MEMBER_VARIABLES

    // CloudRecoBehaviour reference to avoid lookups
    private CloudRecoBehaviour mCloudRecoBehaviour;
    // ImageTracker reference to avoid lookups
    private ImageTracker mImageTracker;
    // reference to the cloud reco scene manager component:
    private ContentManager mContentManager;

    //  array that all textures are loaded into on startup
    private Texture mRequestingTexture;

    // the parent gameobject of the referenced ImageTargetTemplate - reused for all target search results
    private GameObject mParentOfImageTargetTemplate;

    public static long tickCounter;

    public static string textureTest;

    public static bool dataLoaded;

    public static bool questionTrigger;

    public static bool questionAdded;

    public static bool wrongImageScanned;
	
	public static bool texturesLoaded;

    public static string inputQuestion;

    public static string inputSolution;

    public static string alternativeAnswer1;

    public static string alternativeAnswer2;

    public static string alternativeAnswer3;

    public static string dialogButton;
	
	string playButton = "Play sound";

    public static string tp_name;
    public static string tp_info;
    public static string tp_hintImg;
    public static string tp_id;
    public static long toastTimestamp = 0;
	
	GameObject keepAlive;
	KeepAliveScript keepAliveScript;
	
	float w = 0.3f; // proportional width (0..1)
    float h = 0.05f; // proportional height (0..1)
	Rect TextRect = new Rect();
	Rect Text2Rect = new Rect();
	Rect Button1Rect = new Rect();
	Rect QuestionButtonRect = new Rect();
	Rect ContinueButtonRect = new Rect();
	Rect TestToMainMenuButtonRect = new Rect();
	
	bool soundIsPlaying = false;
	bool soundInit = false;
	
	public static ArrayList arTextureArray = new ArrayList();
	public static ArrayList arSoundArray = new ArrayList();
	
	//public AudioSource audioSource;
	Rect PlaySoundRect;
	
	public GUISkin customskin;

    #endregion // PRIVATE_MEMBER_VARIABLES



    #region EXPOSED_PUBLIC_VARIABLES

    /// <summary>
    /// can be set in the Unity inspector to reference a ImageTargetBehaviour that is used for augmentations of new cloud reco results.
    /// </summary>
    public ImageTargetBehaviour ImageTargetTemplate;
	
	public static string[] info;
	
	public static string getTargetFromMetadataUrl = "http://129.241.103.145/getTargetFromMetadata.php";
	
	public static string postQuestionUrl = "http://129.241.103.145/postQuestion.php";
	
	public static string imgHostName = "http://129.241.103.145/AR_images/";
	
	public static string soundHostName = "http://129.241.103.145/AR_sounds/";
	
	
	public static ArrayList arElementsForTPArray = new ArrayList();

    #endregion



    #region ICloudRecoEventHandler_IMPLEMENTATION

    /// <summary>
    /// called when TargetFinder has been initialized successfully
    /// </summary>
    public void OnInitialized()
    {
        // get a reference to the Image Tracker, remember it
        mImageTracker = (ImageTracker)TrackerManager.Instance.GetTracker(Tracker.Type.IMAGE_TRACKER);
        mContentManager = (ContentManager)FindObjectOfType(typeof(ContentManager));
    }

    /// <summary>
    /// visualize initialization errors
    /// </summary>
    public void OnInitError(TargetFinder.InitState initError)
    {
        switch (initError)
        {
            case TargetFinder.InitState.INIT_ERROR_NO_NETWORK_CONNECTION:
                //ErrorMsg.New("Network Unavailable", "Failed to initialize CloudReco because the device has no network connection.", LoadAboutScene);
                break;
            case TargetFinder.InitState.INIT_ERROR_SERVICE_NOT_AVAILABLE:
               //ErrorMsg.New("Service Unavailable", "Failed to initialize CloudReco because the service is not available.", LoadAboutScene);
                break;
        }
    }

    /// <summary>
    /// visualize update errors
    /// </summary>
    public void OnUpdateError(TargetFinder.UpdateState updateError)
    {
        switch (updateError)
        {
            case TargetFinder.UpdateState.UPDATE_ERROR_AUTHORIZATION_FAILED:
                ErrorMsg.New("Authorization Error","The cloud recognition service access keys are incorrect or have expired.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_BAD_FRAME_QUALITY:
                ErrorMsg.New("Poor Camera Image","The camera does not have enough detail, please try again later");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_NO_NETWORK_CONNECTION:
                ErrorMsg.New("Network Unavailable","Please check your internet connection and try again.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_PROJECT_SUSPENDED:
                ErrorMsg.New("Authorization Error","The cloud recognition service has been suspended.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_REQUEST_TIMEOUT:
                ErrorMsg.New("Request Timeout","The network request has timed out, please check your internet connection and try again.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_SERVICE_NOT_AVAILABLE:
                ErrorMsg.New("Service Unavailable","The service is unavailable, please try again later.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_TIMESTAMP_OUT_OF_RANGE:
                ErrorMsg.New("Clock Sync Error","Please update the date and time and try again.");
                break;
            case TargetFinder.UpdateState.UPDATE_ERROR_UPDATE_SDK:
                ErrorMsg.New("Unsupported Version","The application is using an unsupported version of Vuforia.");
                break;
        }
    }

    /// <summary>
    /// when we start scanning, unregister Trackable from the ImageTargetTemplate, then delete all trackables
    /// </summary>
    public void OnStateChanged(bool scanning)
    {
        if (scanning)
        {
            // clear all known trackables
            mImageTracker.TargetFinder.ClearTrackables(false);

            // hide the ImageTargetTemplate
            mContentManager.HideObject();
        }
    }

    /// <summary>
    /// Handles new search results
    /// </summary>
    /// <param name="targetSearchResult"></param>
    public void OnNewSearchResult(TargetFinder.TargetSearchResult targetSearchResult)
    {  
        //Check if the metadata is empty
        if(targetSearchResult.MetaData == null)
        {
            return;
        }
		
		if(targetSearchResult.MetaData != null)
		{
			string metaData_tpId  = targetSearchResult.MetaData; //id of targetPicture from metadata of the Vuforia DB
			StartCoroutine(getInfo(metaData_tpId));
			//StartCoroutine(setTexture());
		}
        // enable the new result with the same ImageTargetBehaviour:
        ImageTargetBehaviour imageTargetBehaviour = mImageTracker.TargetFinder.EnableTracking(targetSearchResult, mParentOfImageTargetTemplate);

        if (imageTargetBehaviour != null)
        {
            // stop the target finder
            mCloudRecoBehaviour.CloudRecoEnabled = false;
            
            // Calls the TargetCreated Method of the SceneManager object to start loading
            // the BookData from the JSON
            mContentManager.TargetCreated(targetSearchResult.MetaData);
        }
    }
	
	//set textures on active 'flate's
	private IEnumerator setTexture ()
	{
		while(!dataLoaded) //wait for other functions to say that data including gui textures are loaded
		{
			yield return new WaitForSeconds(0.1f);	
		}
		int numArElementsToRender = 4;
		if(arTextureArray.Count < numArElementsToRender) //if less than the maximum numer of AR images are to be shown
		{
			numArElementsToRender = arTextureArray.Count;
			
			for(int j = 1;j<(4-numArElementsToRender+1);j++) //disable flate for images not to be shown
			{
				bool tempFlateIsActive = GameObject.Find("flate"+(4-j)).activeInHierarchy;
				if(tempFlateIsActive)
				{
					GameObject.Find("flate"+(4-j)).SetActive(false);
				}
			}
		}
		for(int i =0; i<numArElementsToRender;i++) //set textures on the active 'flate's
		{
			WWW www = new WWW(imgHostName+arTextureArray[i]);
			yield return www;
			string nameOfFlateToUse = "flate"+i;
			GameObject.Find(nameOfFlateToUse).SetActive(true);
			GameObject.Find(nameOfFlateToUse).renderer.material.mainTexture = www.texture;
		}
	}
	
	//get info for a targetPicture including its augmentable elements (images and sounds)
	private IEnumerator getInfo(string id) 
	{
		
		WWWForm form = new WWWForm();
		form.AddField("tp_id", id); 
		WWW getTargetFromMetadata = new WWW(getTargetFromMetadataUrl, form);
		yield return getTargetFromMetadata;
		if ((!string.IsNullOrEmpty(getTargetFromMetadata.error)))
        {
            Debug.Log(getTargetFromMetadata.text);
            print("Error downloading target data: " + getTargetFromMetadata.error);
        }
		else{
			arElementsForTPArray.Clear();
			var returnedString = getTargetFromMetadata.data;
			string[] values =returnedString.Split('&');
			var tpData = values[0]; //Data strictly related to the given target picture, such as name and info
			string[] tpDataSplit = tpData.Split('|');
			tp_name = tpDataSplit[0];
			tp_info = tpDataSplit[1];
			tp_hintImg = tpDataSplit[2];
			tp_id = tpDataSplit[3];
			textureTest = tp_hintImg;
			Debug.Log ("tp_name: "+tp_name+" tp_info: "+tp_info);
				for(int i=1;i<values.Length-1;i++)
				{
					ArrayList arElementValueArray = new ArrayList();
					var arElementData = values[i];
					string[] arElementValues = arElementData.Split('|');
				
						string mediaType = arElementValues[0]; // "sound" or "image" from php
						string mediaField = arElementValues[1]; //ar_s_testField or ar_i_testField from DB
						string ar_element_id = arElementValues[2];
						string are_name = arElementValues[3];
						string url = arElementValues[4];
						arElementValueArray.Add (mediaType); arElementValueArray.Add (mediaField);
						arElementValueArray.Add(ar_element_id); arElementValueArray.Add(are_name); arElementValueArray.Add(url);
						arElementsForTPArray.Add(arElementValueArray);
						Debug.Log(arElementsForTPArray.Count);
			}
				getTargetFromMetadata.Dispose();
        }
		sortAugmentedTextures();
	}
	
	//build an arraylist of textures to use on augmented 'flate's
	void sortAugmentedTextures()	
	{
		arTextureArray.Clear();
		arSoundArray.Clear ();
		for(int i=0;i<arElementsForTPArray.Count;i++)
		{
			ArrayList tempArElementArray = (ArrayList)arElementsForTPArray[i];
			string mediaType = (string)tempArElementArray[0];
			if(mediaType == "image")
			{
				arTextureArray.Add(tempArElementArray[4]); //Add the url of the ar_element to the list of textures to be drawn in the scene
			}
			if(mediaType == "sound")
			{
				arSoundArray.Add(tempArElementArray[4]);
			}
		}
		dataLoaded = true;
	}
	
	//post a question to the DB
	public static IEnumerator postQuestion(){
		Debug.Log ("entered postQuestion");
		WWWForm form = new WWWForm();
		

		form.AddField("tp_id", tp_id); 
		string group = PlayerPrefs.GetString("group");
        string code = PlayerPrefs.GetString("code");
		form.AddField("code",code);
		form.AddField("grp_name",group);
		form.AddField("question",inputQuestion);
		form.AddField("solution",inputSolution);
		form.AddField("alternative1",alternativeAnswer1);
		form.AddField("alternative2",alternativeAnswer2);
		form.AddField("alternative3",alternativeAnswer3);
		inputQuestion = "";
		inputSolution = "";
		Debug.Log ("lets do this");
		WWW postQuestion = new WWW(postQuestionUrl, form);
		yield return postQuestion;
		if ((!string.IsNullOrEmpty(postQuestion.error)))
        {
            Debug.Log(postQuestion.text);
            print("Error posting question: " + postQuestion.error);
        }
		else{
			var returnedString = postQuestion.data;
			Debug.Log (postQuestion.text);
		}
	
	}

    #endregion // ICloudRecoEventHandler_IMPLEMENTATION



    #region UNTIY_MONOBEHAVIOUR_METHODS

    /// <summary>
    /// register for events at the CloudRecoBehaviour
    /// </summary>
    IEnumerator Start()
    {
		texturesLoaded = false;
		
		keepAlive = GameObject.Find("KeepAlive");
		keepAliveScript = (KeepAliveScript) keepAlive.GetComponent(typeof(KeepAliveScript));
		
		PlaySoundRect.width = Screen.width/2;
		PlaySoundRect.height = Screen.height*h;
		PlaySoundRect.x = Screen.width/2 - PlaySoundRect.width/2;
		PlaySoundRect.y = Screen.height - 200-PlaySoundRect.height*2;
		//GameObject mainCamera = GameObject.Find("ARCamera");
		//audioSource = mainCamera.GetComponent<AudioSource>();
		
        tickCounter = 0;
        textureTest = "";
        dataLoaded = false;
        questionTrigger = false;
        questionAdded = false;
        wrongImageScanned = false;
        inputQuestion = "";
        inputSolution = "";
        alternativeAnswer1 = "";
        alternativeAnswer2 = "";
        alternativeAnswer3 = "";
        dialogButton = "Add question";
		
		StartCoroutine(keepAliveScript.getGroupSessionInfo());
		
		while(!keepAliveScript.post)
		{
			yield return new WaitForSeconds(0.1f);
		}
		
		//if(PlayerPrefs.GetString("phase") == "Phase 1"){
		if(KeepAliveScript.current_phase == "Phase 1"){
		GetComponent<Phase1GUI>().enabled = true;
		GetComponent<Phase2GUI>().enabled = false;
		}
		//else if(PlayerPrefs.GetString("phase") == "Phase 2"){
		else if(KeepAliveScript.current_phase == "Phase 2"){
		GetComponent<Phase1GUI>().enabled = false;
		GetComponent<Phase2GUI>().enabled = true;
		}

        // look up the gameobject containing the ImageTargetTemplate:
        mParentOfImageTargetTemplate = ImageTargetTemplate.gameObject;

        // intialize the ErrorMsg class
        ErrorMsg.Init();

        // register this event handler at the cloud reco behaviour
		GameObject cloudRecognition = GameObject.Find("CloudRecognition");
        CloudRecoBehaviour cloudRecoBehaviour = cloudRecognition.GetComponent<CloudRecoBehaviour>();
        if (cloudRecoBehaviour)
        {
            cloudRecoBehaviour.RegisterEventHandler(this);
        }

        // remember cloudRecoBehaviour for later
        mCloudRecoBehaviour = cloudRecoBehaviour;

        // load and remember all used textures:
        mRequestingTexture = Resources.Load("UserInterface/TextureRequesting") as Texture;
		
    }
	
	void Update () 
	{
        if (Application.platform == RuntimePlatform.Android) 
		{
            if (Input.GetKeyUp(KeyCode.Escape)) 
			{
 				Application.LoadLevel(1);
				return;
			}
        }
	}

    /// <summary>
    /// draw the sample GUI and error messages
    /// </summary>
    void OnGUI()
    {	
		GUI.skin = customskin;
		GUI.skin.button.fontSize = Screen.height / 40;
		
		if(dataLoaded)
		{
			if(arSoundArray.Count > 0 && !wrongImageScanned)
			{ //if any sounds are registered to the targetPicture..
				if(GUI.Button(PlaySoundRect, playButton))
				{
					if(!soundInit)
					{
						string soundUrl = (string)CloudRecoEventHandler.arSoundArray[0];
						var www = new WWW(CloudRecoEventHandler.soundHostName+soundUrl);
						audio.clip = www.audioClip;
						soundInit = true;
					}
					
					if(!soundIsPlaying)
					{
						audio.Play();
						soundIsPlaying = true;
						playButton = "Pause";
					}
					else if(soundIsPlaying)
					{
						audio.Pause();
						soundIsPlaying = false;
						playButton = "Play sound";
					}
					
				}
			}
			dialogButton = "Add question";
			
			if(!(textureTest.Equals(PlayerPrefs.GetString("current_image_name"))))
			{
				dialogButton = "Wrong image. Press to rescan";
				
				if(GameObject.Find("InfoText").activeInHierarchy)
				{
					GameObject.Find("InfoText").SetActive(false);
				}
				if(GameObject.Find("InfoBackground").activeInHierarchy)
				{
					GameObject.Find("InfoBackground").SetActive(false);
				}
				if(GameObject.Find("flate0").activeInHierarchy)
				{
					GameObject.Find("flate0").SetActive(false);
				}
				if(GameObject.Find("flate1").activeInHierarchy)
				{
					GameObject.Find("flate1").SetActive(false);
				}
				if(GameObject.Find("flate2").activeInHierarchy)
				{
					GameObject.Find("flate2").SetActive(false);
				}
				if(GameObject.Find("flate3").activeInHierarchy)
				{
					GameObject.Find("flate3").SetActive(false);
				}

				Phase1GUI.QuestionButtonRect.width = Screen.width;
				Phase1GUI.QuestionButtonRect.height = (Screen.height*h)*2;
				Phase1GUI.QuestionButtonRect.x = 0;

				Phase2GUI.AnswerButtonRect.width = Screen.width;
				Phase2GUI.AnswerButtonRect.height = (Screen.height*h)*2;
				Phase2GUI.AnswerButtonRect.x = 0;

				wrongImageScanned = true;
				Phase2GUI.answerButtonDialog = "Wrong painting. Press here to rescan."; //dialogbutton scene2
				
				dialogButton = "asd8";
			}
			else if (!texturesLoaded)
			{
				StartCoroutine(setTexture());
				texturesLoaded = true;
			}
		}

        if (mCloudRecoBehaviour.CloudRecoInitialized && mImageTracker.TargetFinder.IsRequesting())
        {
            // draw the requesting texture
            DrawTexture(mRequestingTexture);
        }
		
		GameObject infoText = GameObject.Find("InfoText");
		TextMesh t = (TextMesh)infoText.GetComponent(typeof(TextMesh));
		tp_info = tp_info.Replace("\\n", "\n");
		t.text = WrapText(tp_info);
		
        // draw error messages in case there were any
        ErrorMsg.Draw();
    }
	
	//Wrap text to make it fit in the augmented reality textbox
	public string WrapText(string text)
	{//30 tokens pr line
		string wrapped= "";
		int counter = 0;
		int maxTegn = 25;
		bool isSpace = false;
		
		foreach(char c in text)
		{
			if(char.IsWhiteSpace(c)){ isSpace = true; }
			else{ isSpace = false; }
			
			if(counter < maxTegn)
			{
				wrapped += c;
				counter++;
			}
			else if(counter >= maxTegn && isSpace)
			{
				
				wrapped += c + "\n";
				counter = 0;
			}
			else if(counter >= maxTegn && !isSpace)
			{
				
				wrapped += c;
			}
		}
		
		return wrapped;
	}

    #endregion // UNTIY_MONOBEHAVIOUR_METHODS



    #region PRIVATE_METHODS

    /// <summary>
    /// draws a textures using UnityGUI
    /// </summary>
    private void DrawTexture(Texture texture)
    {
        // scale texture up by device dependent factor
        int smallerScreenDimension = Screen.width < Screen.height ? Screen.width : Screen.height;
        float deviceDependentScale = smallerScreenDimension / 480f;

        // draw texture at center with given verticalPosition and scale:
        float width = texture.width * deviceDependentScale;
        float height = texture.height * deviceDependentScale;
        float left = (Screen.width * 0.5f) - (width * 0.5f);
        float top = (Screen.height * 0.9f) - (height * 0.5f);
        GUI.DrawTexture(new Rect(left, top, width, height), texture);
    }
    #endregion // PRIVATE_METHODS
}